@@ -511,7 +511,7 @@ modr_safe(GEN x, GEN y)
   q = gdiv(x,y); /* t_REAL */
 
   e = expo(q);
-  if (e >= 0 && nbits2prec(e) > lg(x)) return NULL;
+  if (e >= 0 && nbits2prec(e) > lg(q)) return NULL;
   f = floorr(q);
   if (gsigne(y) < 0 && signe(subri(q,f))) f = addis(f, 1);
   return signe(f)? gsub(x, mulir(f,y)): x;
@@ -3048,10 +3048,14 @@ lift0(GEN x, long v)
     case t_PADIC:
       return gtrunc(x);
 
-    case t_POL: case t_SER:
+    case t_POL:
       y = cgetg_copy(x, &lx); y[1] = x[1];
       for (i=2; i<lx; i++) gel(y,i) = lift0(gel(x,i), v);
-      return y;
+      return normalizepol_lg(y,lx);
+    case t_SER:
+      y = cgetg_copy(x, &lx); y[1] = x[1];
+      for (i=2; i<lx; i++) gel(y,i) = lift0(gel(x,i), v);
+      return normalize(y);
     case t_COMPLEX: case t_RFRAC:
     case t_VEC: case t_COL: case t_MAT:
       y = cgetg_copy(x, &lx);
