@@ -261,7 +261,7 @@ pari_stackcheck_init(void *stack_base)
 void
 pari_stackcheck_init(void *stack_base)
 {
-  PARI_stack_limit = NULL;
+  (void) stack_base; PARI_stack_limit = NULL;
 }
 #endif /* STACK_CHECK */
 
